@@ -41,17 +41,19 @@ setAs("Track", "data.frame",
 )
 
 setAs("Tracks", "data.frame", 
-	function(from)
-		do.call(rbind, lapply(from@tracks, 
-			function(x) rbind(as(x, "data.frame"), NA)))
+	function(from) {
+		l = lapply(from@tracks, function(x) rbind(as(x, "data.frame"), NA))
+		d = do.call(rbind, l)
+		d$Track = rep(names(from@tracks), times = sapply(l, nrow))
+		d
+	}
 )
 
 setAs("TracksCollection", "data.frame", 
 	function(from) {
 		l = lapply(from@tracksCollection, function(x) as(x, "data.frame"))
-		n = sapply(l, nrow)
 		ret = do.call(rbind, l)
-		data.frame(ret, IDs = rep(names(from@tracksCollection), times = n))
+		data.frame(ret, IDs = rep(names(from@tracksCollection), times = sapply(l, nrow)))
 	}
 )
 
@@ -109,7 +111,8 @@ setAs("TracksCollection", "SpatialLines",
 		}
 		
 		SpatialLines(l, CRS(proj4string(from)))
-	})
+	}
+)
 
 
 setAs("TracksCollection", "SpatialLinesDataFrame", 
@@ -117,7 +120,7 @@ setAs("TracksCollection", "SpatialLinesDataFrame",
 		from@tracksCollectionData, match.ID = FALSE)
 )
 
-# Coerce to xts.
+# Coerce to xts; Track is automatic through STIDF.
 
 setAs("Tracks", "xts",
 	function(from)
@@ -225,193 +228,17 @@ plot.TracksCollection <- function(x, y, ..., type = 'l', xlim = stbox(x)[,1],
 		else
 			do.call(segments, args)
 	} else {
-		df = as(x, "data.frame") 
-		cn = coordnames(x)
-		lines(df[[cn[1]]], df[[cn[2]]], col = col, 
-			lwd = lwd, lty = lty, ...)
+		linesTrack = function(x, y, ...) lines(as(x@sp, "SpatialLines"), ...)
+		linesTracks = function(x, y, ...) mapply(linesTrack, x@tracks, ...)
+		invisible(mapply(linesTracks, 
+			x@tracksCollection, col = col, lwd = lwd, lty = lty, type = type, ...))
 	}
 }
 setMethod("plot", "TracksCollection", plot.TracksCollection)
 
-# Provide stcube methods.
+setMethod("plot", "Tracks", function(x, ...) plot(TracksCollection(list(x)), ...))
 
-map3d = function(map, z, ...) {
-	if (!requireNamespace("rgl", quietly = TRUE))
-		stop("rgl required")
-	if(length(map$tiles) != 1)
-		stop("Pass single map tile only.")
-	nx = map$tiles[[1]]$xres
-	ny = map$tiles[[1]]$yres
-	xmin = map$tiles[[1]]$bbox$p1[1]
-	xmax = map$tiles[[1]]$bbox$p2[1]
-	ymin = map$tiles[[1]]$bbox$p1[2]
-	ymax = map$tiles[[1]]$bbox$p2[2]
-	xc = seq(xmin, xmax, len = ny)
-	yc = seq(ymin, ymax, len = nx)
-	col = matrix(data = map$tiles[[1]]$colorData, nrow = ny, ncol = nx)
-	m = matrix(data = z, nrow = ny, ncol = nx)
-	
-	rgl::surface3d(x = xc, y = yc, z = m, col = col, lit=F, ...)
-}
-
-normalize = function(time, by = "week") {
-	tn = as.numeric(time)
-
-	switch(by,
-		minute = (tn %% 60),
-		hour = (tn %% 3600) / 60 , # decimal minute of the hour
-		day = (tn %% (3600 * 24)) / 3600, # decimal hour of the day
-		week = (tn %% (3600 * 24 * 7)) / 24 / 3600, # decimal day of the week
-		stop(paste("unknown value for by: ", by)))
-}
-
-if(!isGeneric("stcube"))
-	setGeneric("stcube", function(x, ...)
-		standardGeneric("stcube"))
-
-setMethod("stcube", signature(x = "Track"),
-	function(x, xlab = "x", ylab = "y", zlab = "t", type = "l", aspect, xlim,
-		ylim, zlim, showMap = FALSE, mapType = "osm", ..., y, z) {
-		# "y" and "z" are ignored, but included in the method signature to avoid
-		# passing them twice to plot3d().
-		if (!requireNamespace("rgl", quietly = TRUE))
-			stop("rgl required")
-		if (!requireNamespace("OpenStreetMap", quietly = TRUE))
-			stop("OpenStreetMap required")
-		coords = coordinates(x@sp)
-		time = index(x@time)
-		time <- time - min(time) # seconds from start
-		if(missing(aspect))
-			aspect = if((asp = mapasp(x@sp)) == "iso") "iso" else c(1, asp, 1)
-		if(missing(xlim))
-			xlim = range(coords[, 1])
-		if(missing(ylim))
-			ylim = range(coords[, 2])
-		if(missing(zlim))
-			zlim = range(time)
-		# If the basemap is to be shown, fetch map tile first to allow for
-		# rendering everything in one go.
-		if (showMap) {
-			# Required by openmap().
-			if (!requireNamespace("raster", quietly = TRUE))
-				stop("raster required")
-			# require(raster)
-			map = OpenStreetMap::openmap(upperLeft = c(ylim[2], xlim[1]),
-				lowerRight = c(ylim[1], xlim[2]), type = mapType)
-			map = OpenStreetMap::openproj(x = map, projection = proj4string(x))
-		}
-		rgl::plot3d(x = coords[, 1], y = coords[, 2], z = time, xlab = xlab,
-			ylab = ylab, zlab = zlab, type = type, aspect = aspect, xlim = xlim,
-			ylim = ylim, zlim = zlim, ...)
-		if (showMap)
-			map3d(map = map, z = time[1])
-	}
-)
-
-setMethod("stcube", signature(x = "Tracks"),
-	function(x, xlab = "x", ylab = "y", zlab = "t", type = "l", aspect, xlim,
-		ylim, zlim, showMap = FALSE, mapType = "osm", normalizeBy = "week",
-		mapZoom=NULL, ..., y, z, col) {
-		# "y", "z" and "col" are ignored, but included in the method signature
-		# to avoid passing them twice to plot3d().
-		if (!requireNamespace("rgl", quietly = TRUE))
-			stop("rgl required")
-		if (!requireNamespace("OpenStreetMap", quietly = TRUE))
-			stop("OpenStreetMap required")
-		dim = dim(x@tracks[[1]])["geometries"]
-		coordsAll = do.call(rbind, lapply(x@tracks, function(x) coordinates(x@sp)))
-		timeAll = normalize(do.call(c, lapply(x@tracks,
-			function(x) index(x@time))), normalizeBy)
-		col = rainbow(length(x@tracks))
-		if(missing(aspect))
-			# mapasp() processes objects of class Spatial* only.
-			aspect = if((asp = mapasp(as(x, "SpatialLines"))) == "iso") "iso" else c(1, asp, 1)
-		if(missing(xlim))
-			xlim = range(coordsAll[, 1])
-		if(missing(ylim))
-			ylim = range(coordsAll[, 2])
-		if(missing(zlim))
-			zlim = range(timeAll)
-		# If the basemap is to be shown, fetch map tile first to allow for
-		# rendering everything in one go.
-		if(showMap) {
-			# Required by openmap().
-			if (!requireNamespace("raster", quietly = TRUE))
-				stop("raster required")
-			map = OpenStreetMap::openmap(upperLeft = c(ylim[2], xlim[1]),
-				lowerRight = c(ylim[1], xlim[2]), zoom=mapZoom, type = mapType)
-			map = OpenStreetMap::openproj(x = map, projection = proj4string(x))
-		}
-		rgl::plot3d(x = coordsAll[1:dim, 1], y = coordsAll[1:dim, 2],
-			z = timeAll[1:dim], xlab = xlab, ylab = ylab, zlab = zlab,
-			type = type, col = col[1], aspect = aspect, xlim = xlim,
-			ylim = ylim, zlim = zlim, ...)
-		tracks = x@tracks[-1]
-		for(t in seq_along(tracks)) {
-			coords = coordinates(tracks[[t]]@sp)
-			time = normalize(index(tracks[[t]]@time), normalizeBy)
-			rgl::lines3d(x = coords[, 1], y = coords[, 2], z = time, col = col[t+1])
-		}
-		if(showMap)
-			map3d(map = map, z = timeAll[1])
-	}
-)
-
-setMethod("stcube", signature(x = "TracksCollection"),
-	function(x, xlab = "x", ylab = "y", zlab = "t", type = "l", aspect, xlim,
-		ylim, zlim, showMap = FALSE, mapType = "osm", normalizeBy = "week",
-		mapZoom=NULL, ..., y, z, col) {
-		# "y", "z" and "col" are ignored, but included in the method signature
-		# to avoid passing them twice to plot3d().
-		if (!requireNamespace("rgl", quietly = TRUE))
-			stop("rgl required")
-		if (!requireNamespace("OpenStreetMap", quietly = TRUE))
-			stop("OpenStreetMap required")
-		dim = dim(x@tracksCollection[[1]]@tracks[[1]])["geometries"]
-		coordsAll = do.call(rbind, lapply(x@tracksCollection,
-			function(x) do.call(rbind, lapply(x@tracks, function(y) coordinates(y@sp)))))
-		timeAll = normalize(do.call(c, lapply(x@tracksCollection,
-			function(x) do.call(c, lapply(x@tracks,
-				function(y) index(y@time))))), normalizeBy)
-		col = rainbow(length(x@tracksCollection))
-		if(missing(aspect))
-			# mapasp() processes objects of class Spatial* only.
-			aspect = if((asp = mapasp(as(x, "SpatialLines"))) == "iso") "iso" else c(1, asp, 1)
-		if(missing(xlim))
-			xlim = range(coordsAll[, 1])
-		if(missing(ylim))
-			ylim = range(coordsAll[, 2])
-		if(missing(zlim))
-			zlim = range(timeAll)
-		# If the basemap is to be shown, fetch map tile first to allow for
-		# rendering everything in one go.
-		if(showMap) {
-			# Required by openmap().
-			if (!requireNamespace("raster", quietly = TRUE))
-				stop("raster required")
-			map = OpenStreetMap::openmap(upperLeft = c(ylim[2], xlim[1]), 
-				lowerRight = c(ylim[1], xlim[2]), zoom=mapZoom, type = mapType)
-			map = OpenStreetMap::openproj(x = map, projection = proj4string(x))
-		}
-		rgl::plot3d(x = coordsAll[1:dim, 1], y = coordsAll[1:dim, 2],
-			z = timeAll[1:dim], xlab = xlab, ylab = ylab, zlab = zlab,
-			type = type, col = col[1], aspect = aspect, xlim = xlim,
-			ylim = ylim, zlim = zlim, ...)
-		for(tz in seq_along(x@tracksCollection)) {
-			if(tz == 1)
-				tracks = x@tracksCollection[[tz]]@tracks[-1]
-			else
-				tracks = x@tracksCollection[[tz]]@tracks
-			for(t in seq_along(tracks)) {
-				coords = coordinates(tracks[[t]]@sp)
-				time = normalize(index(tracks[[t]]@time), normalizeBy)
-				rgl::lines3d(x = coords[, 1], y = coords[, 2], z = time, col = col[tz])
-			}
-		}
-		if(showMap)
-			map3d(map = map, z = timeAll[1])
-	}
-)
+setMethod("plot", c("Track", "missing"), function(x, ...) plot(Tracks(list(x)), ...))
 
 # Provide coordnames methods.
 
@@ -419,9 +246,7 @@ setMethod("coordnames", "Track", function(x) coordnames(x@sp))
 
 setMethod("coordnames", "Tracks", function(x) coordnames(x@tracks[[1]]))
 
-setMethod("coordnames", "TracksCollection",
-	function(x) coordnames(x@tracksCollection[[1]])
-)
+setMethod("coordnames", "TracksCollection", function(x) coordnames(x@tracksCollection[[1]]))
 
 # Provide stbox methods.
 
@@ -469,130 +294,15 @@ setMethod("bbox", "Tracks", function(obj) t(stbox(obj)[1:2]))
 
 setMethod("bbox", "TracksCollection", function(obj) t(stbox(obj)[1:2]))
 
-# Provide generalize methods.
-
-if(!isGeneric("generalize"))
-	setGeneric("generalize", function(t, FUN = mean, ...)
-		standardGeneric("generalize"))
-
-generalize.Track <- function(t, FUN = mean, ..., timeInterval, distance, n, tol, toPoints) {
-	if (sum(!c(missing(timeInterval), missing(distance), missing(n))) != 1)
-		stop("exactly one parameter from (timeInterval, distance, n) has to be specified")
-	if(!missing(timeInterval)) {
-		origin = index(t@time)
-		cut = cut(origin, timeInterval)
-		segmentLengths = rle(as.numeric(cut))$lengths
-	} 
-	if (!missing(distance)) {
-		# Total distances from each point to the first one.
-		origin = c(0, cumsum(t@connections$distance))
-		cut = floor(origin / distance)
-		segmentLengths = rle(cut)$lengths
-	} 
-	if (!missing(n)) {
-		dim = dim(t)["geometries"]
-		if(n != 1 && dim / n > 1) {
-			rep = floor((dim-n)/(n-1) + 1)
-			mod = (dim-n) %% (n-1)
-			if(mod == 0)
-				segmentLengths = rep(n, rep)
-			else
-				segmentLengths = c(rep(n, rep), mod + 1)
-		} else
-			segmentLengths = dim
-	} 
-	# Update segment lengths to consider all segments for generalisation. In
-	# case the cut-point falls between two points of the track to be
-	# generalised, attach the next point to the current segment. If the cut-
-	# point matches a point of the track, leave everything as is.
-	toIndex = cumsum(segmentLengths)
-	segmentLengths_ = integer()
-	for(i in seq_along(segmentLengths)) {
-		if (i == length(segmentLengths)
-			|| (!missing(timeInterval) && origin[toIndex[i]] %in% seq(origin[1], origin[length(origin)], timeInterval))
-			|| (!missing(distance) && origin[toIndex[i]] > 0 && origin[toIndex[i]] %% distance == 0)
-			|| (!missing(n)))
-			segmentLengths_[i] = segmentLengths[i]
-		else { 
-			segmentLengths_[i] = segmentLengths[i] + 1
-			if(i == length(segmentLengths) - 1 && segmentLengths[i+1] == 1)
-				break()
-		}
-	}
-	segmentLengths = segmentLengths_
-	# Aggregate over each segment.
-	stidfs = list()
-	endTime = NULL
-	for(i in seq_along(segmentLengths)) {
-		from = if(i == 1) 1 else tail(cumsum(segmentLengths[1:(i-1)]), n = 1) - (i-2)
-		to = from + segmentLengths[i] - 1
-		if(!missing(toPoints) && toPoints)
-			sp = t@sp[(from+to)/2]
-		else {
-			l = Lines(list(Line(t@sp[from:to])), paste("L", i, sep = ""))
-			sp = SpatialLines(list(l), proj4string = CRS(proj4string(t)))
-			if(!missing(tol) && nrow(coordinates(sp)[[1]][[1]]) > 1) {
-				if (!requireNamespace("rgeos", quietly = TRUE))
-					stop("rgeos required for tolerance")
-				sp = rgeos::gSimplify(spgeom = sp, tol = tol, 
-					topologyPreserve = TRUE)
-			}
-		}
-		time = t@time[from]
-		if (is.null(endTime)) {
-			endTime = t@endTime[to]
-			tz = attr(endTime, "tzone")
-		} else
-			endTime = c(endTime, t@endTime[to])
-		data = data.frame(lapply(t@data[from:to, , drop = FALSE], FUN, ...)) # EP added ...
-		#stidfs = c(stidfs, STIDF(sp, time, data, t@endTime[to]))
-		stidfs = c(stidfs, STIDF(sp, time, data))
-	}
-	stidf = do.call(rbind, stidfs)
-	# Provide a workaround, since rbind'ing objects of class POSIXct as used
-	# in the "endTime" slot of STIDF objects does not work properly.
-	attr(endTime, "tzone") = tz
-	stidf@endTime = endTime
-	Track(stidf)
-}
-
-setMethod("generalize", signature(t = "Track"), generalize.Track)
-
-setMethod("generalize", signature(t = "Tracks"),
-	function(t, FUN = mean, ...) {
-		t@tracks = lapply(t@tracks,
-			function(x) generalize(x, FUN, ...))
-		t
-	}
-)
-
-setMethod("generalize", signature(t = "TracksCollection"),
-	function(t, FUN = mean, ...) {
-		t@tracksCollection = lapply(t@tracksCollection,
-			function(x) generalize(x, FUN, ...))
-		t
-	}
-)
-
 # Provide over methods.
 
-setMethod("over", c("Track", "Spatial"),
-	function(x, y, ...) {
-		over(as(x, "SpatialLines"), y, ...)
-	}
-)
+setMethod("over", c("Track", "Spatial"), function(x, y, ...) over(as(x, "SpatialLines"), y, ...))
+setMethod("over", c("Tracks", "Spatial"), function(x, y, ...) over(as(x, "SpatialLines"), y, ...))
+setMethod("over", c("TracksCollection", "Spatial"), function(x, y, ...) over(as(x, "SpatialLines"), y, ...))
 
-setMethod("over", c("Tracks", "Spatial"),
-	function(x, y, ...) {
-		over(as(x, "SpatialLines"), y, ...)
-	}
-)
-
-setMethod("over", c("TracksCollection", "Spatial"),
-	function(x, y, ...) {
-		over(as(x, "SpatialLines"), y, ...)
-	}
-)
+setMethod("over", c("Track", "xts"), function(x, y, ...) over(as(x, "xts"), y, ...))
+setMethod("over", c("Tracks", "xts"), function(x, y, ...) over(as(x, "xts"), y, ...))
+setMethod("over", c("TracksCollection", "xts"), function(x, y, ...) over(as(x, "xts"), y, ...))
 
 # Provide aggregate methods.
 
@@ -630,6 +340,7 @@ summary.Track = function(object, ...) {
 	obj = list()
 	obj$class = class(object)
 	obj$dim = dim(object)
+	obj$stbox = stbox(object)
 	obj$sp = summary(object@sp)
 	obj$time = summary(object@time)
 	obj$data = summary(object@data)
@@ -645,6 +356,8 @@ print.summary.Track = function(x, ...) {
 	cat(" with Dimensions: (")
 	cat(paste(x$dim, collapse = ", "))
 	cat(")\n")
+	cat("[[stbox]]\n")
+	print(x$stbox)
 	cat("[[Spatial:]]\n")
 	print(x$sp)
 	cat("[[Temporal:]]\n")
@@ -660,6 +373,7 @@ summary.Tracks = function(object, ...) {
 	obj = list()
 	obj$class = class(object)
 	obj$dim = dim(object)
+	obj$stbox = stbox(object)
 	obj$sp = summary(do.call(rbind, lapply(object@tracks, function(x) x@sp)))
 	obj$time = summary(do.call(rbind, lapply(object@tracks, function(x) x@time)))
 	obj$data = summary(do.call(rbind, lapply(object@tracks, function(x) x@data)))
@@ -675,6 +389,8 @@ print.summary.Tracks = function(x, ...) {
 	cat(" with Dimensions (tracks, geometries): (")
 	cat(paste(x$dim, collapse = ", "))
 	cat(")\n")
+	cat("[[stbox]]\n")
+	print(x$stbox)
 	cat("[[Spatial:]]\n")
 	print(x$sp)
 	cat("[[Temporal:]]\n")
@@ -690,6 +406,7 @@ summary.TracksCollection = function(object, ...) {
 	obj = list()
 	obj$class = class(object)
 	obj$dim = dim(object)
+	obj$stbox = stbox(object)
 	obj$sp = summary(do.call(rbind, lapply(object@tracksCollection,
 		function(x) do.call(rbind, lapply(x@tracks, function(y) y@sp)))))
 	obj$time = summary(do.call(rbind, lapply(object@tracksCollection,
@@ -709,6 +426,8 @@ print.summary.TracksCollection = function(x, ...) {
 	cat(" with Dimensions (IDs, tracks, geometries): (")
 	cat(paste(x$dim, collapse = ", "))
 	cat(")\n")
+	cat("[[stbox]]\n")
+	print(x$stbox)
 	cat("[[Spatial:]]\n")
 	print(x$sp)
 	cat("[[Temporal:]]\n")
@@ -721,18 +440,29 @@ print.summary.TracksCollection = function(x, ...) {
 }
 
 # Provide selection methods.
+subs.Track <- function(x, i, j, ..., drop = TRUE) {
+	Track(as(x, "STIDF")[i, j, ..., drop = drop])
+}
+
+setMethod("[", "Track", subs.Track)
 
 subs.Tracks <- function(x, i, j, ... , drop = TRUE) {
 	if (missing(i))
 		i = 1:length(x@tracks)
 	else if (is(i, "Spatial"))
 		i = which(!is.na(over(x, geometry(i))))
+	else if (is.character(i) && length(i) == 1 && !(i %in% names(x@tracks))) # i time:
+		i = sapply(x@tracks, function(x) nrow(as(x, "xts")[i]) > 0)
 	else if (is.logical(i))
 		i = which(i)
-	if (drop && length(i) == 1)
+	if (length(i) == 1 && drop)
 		x@tracks[[i]]
-	else
-		Tracks(x@tracks[i], x@tracksData[i,j,drop=FALSE])
+	else {
+		if (!any(i))
+			NULL
+		else 
+			Tracks(x@tracks[i], x@tracksData[i, j, drop=FALSE])
+	}
 }
 
 setMethod("[", "Tracks", subs.Tracks)
@@ -763,11 +493,16 @@ subs.TracksCollection <- function(x, i, j, ... , drop = TRUE) {
 		s = 1:length(x@tracksCollection)
 	else if (is(i, "Spatial"))
 		s = which(!is.na(over(x, geometry(i))))
+	else if (is.character(i) && length(i) == 1 && !(i %in% names(x@tracksCollection))) # i time:
+		i = lapply(x@tracksCollection, function(x) 
+			which(sapply(x@tracks, function(x) nrow(as(x, "xts")[i]) > 0)))
 	else if (is.logical(i))
 		s = which(i)
-	else if (is.list(i)) {
-		stopifnot(all(sapply(i, function(element) is.numeric(element))))
-		s = which(sapply(i, function(element) length(element) > 0))
+	else
+		s = i
+	if (!missing(i) && is.list(i)) { # might have been created by the lappty() above
+		stopifnot(all(sapply(i, function(x) is.numeric(x))))
+		s = which(sapply(i, function(x) length(x) > 0))
 		for(index in seq_along(s)) {
 			tz = x@tracksCollection[[s[index]]]
 			tz@tracks = tz@tracks[i[[s[index]]]]
@@ -775,9 +510,7 @@ subs.TracksCollection <- function(x, i, j, ... , drop = TRUE) {
 			# Write back the just processed Tracks element.
 			x@tracksCollection[[s[index]]] = tz
 		}
-	}
-	else
-		s = i
+	} 
 	# Drop data structure. Only relevant in case one single Tracks/Track element
 	# have/has been selected. Multiple Tracks elements are always returned as
 	# TracksCollection, independently of whether drop is true or false.
@@ -828,10 +561,11 @@ setMethod("[[", c("TracksCollection", "ANY", "missing"),
 
 setReplaceMethod("[[", c("Track", "ANY", "missing", "ANY"), 
 	function(x, i, j, value) {
-		if(i %in% names(x@data))
-			x@data[[i]] = value	
-		else if(i %in% names(x@connections))
+		if (i %in% names(x@connections)) {
+			warning(paste("replacing", i, "in connections slot"))
 			x@connections[[i]] = value
+		} else
+			x@data[[i]] = value
 		x 	
 	}
 )
@@ -913,7 +647,7 @@ setReplaceMethod("$", "TracksCollection",
 	}
 )
 
-# Provide stack, unstack and concatenate methods.
+# Provide stack, unstack and concatenate c() methods.
 
 stack.TracksCollection = function (x, select, ...) {
 	stopifnot(missing(select))
@@ -929,3 +663,22 @@ unstack.TracksCollection = function(x, form, ...) {
 	TracksCollection(lapply(split(x@tracksCollection, form), 
 		function(x) do.call(c, x)))
 }
+
+# approx coordinates and attributes for specific new time points, 
+approxTrack = function(track, when, ..., n = 50, by, FUN = stats::approx, warn.if.outside = TRUE) {
+	x = index(track)
+	if (missing(when)) {
+		if (missing(by))
+			when = seq(min(x), max(x), length.out = n)
+		else
+			when = seq(min(x), max(x), by = by)
+	} else if (warn.if.outside &&
+		(min(when) < min(index(track)) || max(when) > max(index(track))))
+			warning("approxTrack: approximating outside data range")
+	p = apply(coordinates(track), 2, function(y) FUN(x, y, xout = when, n = n, ...)$y)
+	d = data.frame(lapply(track@data, function(y) FUN(x, y, xout = when, n = n, ... )$y))
+	Track(STIDF(SpatialPoints(p, CRS(proj4string(track))), when, d))
+}
+approxTracks = function(tr, ...) Tracks(lapply(tr@tracks, function(x) approxTrack(x,...)))
+approxTracksCollection = function(tc, ...)
+	TracksCollection(lapply(tc@tracksCollection, function(x) approxTracks(x,...)))
